summaryrefslogtreecommitdiff
path: root/MdePkg/Library/BaseExtractGuidedSectionLib/BaseExtractGuidedSectionLib.c
diff options
context:
space:
mode:
Diffstat (limited to 'MdePkg/Library/BaseExtractGuidedSectionLib/BaseExtractGuidedSectionLib.c')
-rw-r--r--MdePkg/Library/BaseExtractGuidedSectionLib/BaseExtractGuidedSectionLib.c12
1 files changed, 6 insertions, 6 deletions
diff --git a/MdePkg/Library/BaseExtractGuidedSectionLib/BaseExtractGuidedSectionLib.c b/MdePkg/Library/BaseExtractGuidedSectionLib/BaseExtractGuidedSectionLib.c
index ce289d2d6..c3978c9b5 100644
--- a/MdePkg/Library/BaseExtractGuidedSectionLib/BaseExtractGuidedSectionLib.c
+++ b/MdePkg/Library/BaseExtractGuidedSectionLib/BaseExtractGuidedSectionLib.c
@@ -34,7 +34,7 @@ typedef struct {
the registered guid and Handler list. When it is initialized, it will be directly returned.
Or, HandlerInfo table will be initialized in this function.
- @param[in, out] InfoPointer The pointer to the handler info structure.
+ @param[in, out] InfoPointer The pointer to the handler information structure.
@retval RETURN_SUCCESS HandlerInfo table can be used to store guid and function tables.
@retval RETURN_OUT_OF_RESOURCES HandlerInfo table address is not writable.
@@ -52,23 +52,23 @@ GetExtractGuidedSectionHandlerInfo (
HandlerInfo = (EXTRACT_GUIDED_SECTION_HANDLER_INFO*)(VOID*)(UINTN) PcdGet64 (PcdGuidedExtractHandlerTableAddress);
//
// First check whether the handler info structure is initialized.
//
if (HandlerInfo->Signature == EXTRACT_HANDLER_INFO_SIGNATURE) {
//
// The handler info has been initialized and is returned.
//
*InfoPointer = HandlerInfo;
return RETURN_SUCCESS;
}
//
// Try to initialize the handler info structure
//
HandlerInfo->Signature = EXTRACT_HANDLER_INFO_SIGNATURE;
if (HandlerInfo->Signature != EXTRACT_HANDLER_INFO_SIGNATURE) {
//
// The handler info structure was not writeable because the memory is not ready.
//
*InfoPointer = NULL;
return RETURN_OUT_OF_RESOURCES;
@@ -284,7 +284,7 @@ ExtractGuidedSectionGetInfo (
for (Index = 0; Index < HandlerInfo->NumberOfExtractHandler; Index ++) {
if (CompareGuid (HandlerInfo->ExtractHandlerGuidTable + Index, &(((EFI_GUID_DEFINED_SECTION *) InputSection)->SectionDefinitionGuid))) {
//
// Call the match handler to get info for the input section data.
//
return HandlerInfo->ExtractGetInfoHandlerTable [Index] (
InputSection,
@@ -52,23 +52,23 @@ GetExtractGuidedSectionHandlerInfo (
HandlerInfo = (EXTRACT_GUIDED_SECTION_HANDLER_INFO*)(VOID*)(UINTN) PcdGet64 (PcdGuidedExtractHandlerTableAddress);
//
- // First check whether the handler info structure is initialized.
+ // First check whether the handler information structure is initialized.
//
if (HandlerInfo->Signature == EXTRACT_HANDLER_INFO_SIGNATURE) {
@@ -52,23 +52,23 @@ GetExtractGuidedSectionHandlerInfo (
if (HandlerInfo->Signature == EXTRACT_HANDLER_INFO_SIGNATURE) {
//
- // The handler info has been initialized and is returned.
+ // The handler information has been initialized and is returned.
//
*InfoPointer = HandlerInfo;
@@ -52,23 +52,23 @@ GetExtractGuidedSectionHandlerInfo (
}
//
- // Try to initialize the handler info structure
+ // Try to initialize the handler information structure
//
HandlerInfo->Signature = EXTRACT_HANDLER_INFO_SIGNATURE;
@@ -52,23 +52,23 @@ GetExtractGuidedSectionHandlerInfo (
if (HandlerInfo->Signature != EXTRACT_HANDLER_INFO_SIGNATURE) {
//
- // The handler info structure was not writeable because the memory is not ready.
+ // The handler information structure was not writeable because the memory is not ready.
//
*InfoPointer = NULL;
@@ -284,7 +284,7 @@ ExtractGuidedSectionGetInfo (
if (CompareGuid (HandlerInfo->ExtractHandlerGuidTable + Index, &(((EFI_GUID_DEFINED_SECTION *) InputSection)->SectionDefinitionGuid))) {
//
- // Call the match handler to get info for the input section data.
+ // Call the match handler to get information for the input section data.
//
return HandlerInfo->ExtractGetInfoHandlerTable [Index] (